@@ -980,10 +980,26 @@ def list_or_single(iterable):
 	>>> list_or_single(['a'])
 	'a'
 	"""
-	result = list(iterable)
-	if len(result) == 1:
-		result = result[0]
-	return result
+	warnings.warn("Use maybe_single", DeprecationWarning)
+	return maybe_single(list(iterable))
+
+
+def maybe_single(sequence):
+	"""
+	Given a sequence, if it contains exactly one item,
+	return that item, otherwise return the sequence.
+	Correlary function to always_iterable.
+
+	>>> maybe_single(tuple('abcd'))
+	('a', 'b', 'c', 'd')
+	>>> maybe_single(['a'])
+	'a'
+	"""
+	try:
+		single, = sequence
+	except ValueError:
+		return sequence
+	return single
 
 
 def self_product(iterable):
